package com.dsic.gj_erp.ws;

import com.alibaba.fastjson.JSONObject;
import com.corundumstudio.socketio.SocketIOClient;
import com.corundumstudio.socketio.SocketIOServer;
import com.corundumstudio.socketio.annotation.OnConnect;
import com.corundumstudio.socketio.annotation.OnDisconnect;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

@Slf4j
@Component
@AllArgsConstructor
public class WsHandler {

    private final SocketIOServer socketIOServer;

    private final WsProperties properties;

    @OnDisconnect
    public void onDisconnect(SocketIOClient client) {
        if (client.getHandshakeData().getLocal().getPort()==properties.getPort()){
            Map<String, List<String>> urlParams = client.getHandshakeData().getUrlParams();
            log.info("--------------------客户端已断开连接-------------------- {}", urlParams);
        }
    }

    @OnConnect
    public void onConnect(SocketIOClient client) {
        if (client.getHandshakeData().getLocal().getPort()==properties.getPort()){
            log.info("{}", client);
            Map<String, List<String>> urlParams = client.getHandshakeData().getUrlParams();
            log.info("链接开启，urlParams：{}", urlParams);
        }
    }

    public void sendSlComplete(JSONObject object) {
        socketIOServer.getBroadcastOperations().sendEvent("slComplete", object);
    }

    public void sendPwComplete(JSONObject object) {
        socketIOServer.getBroadcastOperations().sendEvent("pwComplete", object);
    }

    public void sendLLComplete(JSONObject object) {
        socketIOServer.getBroadcastOperations().sendEvent("llComplete", object);
    }

    public void sendHXComplete(JSONObject object) {
        socketIOServer.getBroadcastOperations().sendEvent("hxComplete", object);
    }

    public void sendQGComplete(JSONObject object) {
        socketIOServer.getBroadcastOperations().sendEvent("qgComplete", object);
    }
}
